@@ -1,15 +1,13 @@
 #!/usr/bin/env python
 
-# sfutils
-
 """Shotfile reading with pure python
 
-https://www.aug.ipp.mpg.de/~git/pyaug/sfread.html
+https://www.aug.ipp.mpg.de/aug/manuals/aug_sfutils
 
 """
 __author__  = 'Giovanni Tardini (Tel. 1898)'
-__version__ = '0.3.3'
-__date__    = '14.10.2021'
+__version__ = '0.3.4'
+__date__    = '15.10.2021'
 
 import sys, logging
 
@@ -20,9 +18,10 @@ logger = logging.getLogger('aug_sfutils')
 logger.addHandler(hnd)
 logger.setLevel(logging.INFO)
 
-try:
+try: # wrapper classes, available only with afs-client and kerberos access
     from .ww import *
     from .sfh import *
+    from .journal import *
 except:
     logger.warning('ww and sfh not loaded, SFREAD and EQU available')
     pass
