@@ -5,14 +5,7 @@ import numpy as np
 
 from . import sfobj, SFREAD, parse_kwargs
 
-fmt = logging.Formatter('%(asctime)s | %(name)s | %(levelname)s: %(message)s', '%Y-%m-%d %H:%M:%S')
-hnd = logging.StreamHandler()
-hnd.setFormatter(fmt)
-hnd.setLevel(level=logging.INFO)
-logger = logging.getLogger('sf2equ')
-logger.addHandler(hnd)
-logger.setLevel(logging.INFO)
-logger.propagate = False
+logger = logging.getLogger('aug_sfutils.sf2equ')
 
 
 class EQU:
