@@ -7,6 +7,7 @@ from . import sfdics, sfhread, sfobj, manage_ed, parse_kwargs, str_byt, libddc
 PPGCLOCK = [1e-6, 1e-5, 1e-4, 1e-3]
 
 logger = logging.getLogger('aug_sfutils.sfread')
+date_fmt = '%Y-%m-%d'
 
 
 def read_other_sf(*args, **kwargs):
@@ -31,10 +32,10 @@ def parse_url(url, blen=100):
                 import urllib
                 url_lib = 'urllib'
             except:
-                logger.error('No URL lib found, exiting')
+                logger.error('No urllib(2, 3) found')
                 return None
-    logger.info('URL reading with %s' %url_lib)
-    url_not_found = 'URLs %s not found, exiting' %url
+
+    url_not_found = 'URLs %s not found' %url
     if url_lib == 'urllib3':
         http = urllib3.PoolManager()
         try:
@@ -47,13 +48,13 @@ def parse_url(url, blen=100):
         try:
             bshot = urllib2.urlopen(url).read(blen)
         except:
-            logger.exception(url_not_found)
+            logger.error(url_not_found)
             return None
     elif url_lib == 'urllib':
         try:
             bshot = request.urlopen(url).read()
         except:
-            logger.exception(url_not_found)
+            logger.error(url_not_found)
             return None
 
     return bshot
@@ -63,6 +64,12 @@ def getlastshot():
     """
     Gets last shot number from the AUG webpage(s)
     """
+
+    try:
+        from . import journal
+        return journal.getLastShot()
+    except:
+        pass
     url1 = 'http://ssr-mir.aug.ipp.mpg.de:9090/Diag/ShotNumber.dta'
     url2 = 'https://www.aug.ipp.mpg.de/aug/local/aug_only/journal_today_2.html'
     bshot = parse_url(url1)
@@ -85,7 +92,7 @@ def getlastshot():
         try:
             nshot = int(sshot)
         except:
-            logger.exception('ERROR sfread.getlastshot: cannot convert string %s to integer' %sshot)
+            logger.error('ERROR sfread.getlastshot: cannot convert string %s to integer' %sshot)
             nshot = None
 
     return nshot
